@@ -1,14 +1,18 @@
+import os
 from mmisdk import CustodianFactory
 
 # Instantiate the factory
 factory = CustodianFactory()
 
+# Grab your token from the environment, or anywhere else
+token = os.environ["MMISDK_TOKEN_BITGO_TEST"]
+
 # Create the custodian, using the factory
-custodian = factory.create_for("bitgo-test", "YOUR-TOKEN-BITGO-TEST")
+custodian = factory.create_for("bitgo-test", token)
 
 # Build tx details
 tx_params = {
-    "from_": "0xeddb59689e4ec3931b8d42d615c0d4a7a3a208e7",
+    "from": "0xeddb59689e4ec3931b8d42d615c0d4a7a3a208e7",
     "to": "0xb22505ee2aac7d52d4a218f5877cdbae3bbeec75",
     "value": "999000000",  # in Wei
     "gas": "123456",
