@@ -1,16 +1,20 @@
+import os
 from mmisdk import CustodianFactory
 
 # Instantiate the factory
 factory = CustodianFactory()
 
+# Grab your token from the environment, or anywhere else
+token = os.environ["MMISDK_TOKEN_CACTUS_DEV"]
+
 # Create the custodian, using the factory
-custodian = factory.create_for("cactus-dev", "YOUR-REFRESH-TOKEN-CACTUS-DEV")
+custodian = factory.create_for("cactus-dev", token)
 
 # Build tx details
 tx_params = {
-    "from_": "0xFA42B2eCf59abD6d6BD4BF07021D870E2FC0eF20",
+    "from": "0xFA42B2eCf59abD6d6BD4BF07021D870E2FC0eF20",
     "to": "0x7dc55e5C19c43FF6f027d0CeF656B2E1513916e6",
-    "value": "100000000000000000",  # in Wei
+    "value": "100000000",  # in Wei
     "gas": "133997",
     "gasPrice": "200000000000",
 }
