@@ -1,14 +1,18 @@
+import os
 from mmisdk import CustodianFactory
 
 # Instantiate the factory
 factory = CustodianFactory()
 
+# Grab your token from the environment, or anywhere else
+token = os.environ["MMISDK_TOKEN_QREDO_DEV"]
+
 # Create the custodian, using the factory
-custodian = factory.create_for("qredo-dev", "YOUR-REFRESH-TOKEN-QREDO-DEV")
+custodian = factory.create_for("qredo-dev", token)
 
 # Build tx details
 tx_params = {
-    "from_": "0x62468FD916bF27A3b76d3de2e5280e53078e13E1",
+    "from": "0x62468FD916bF27A3b76d3de2e5280e53078e13E1",
     "to": "0x62468FD916bF27A3b76d3de2e5280e53078e13E1",
     "value": "100000000000000000",  # in Wei
     "gas": "21000",
@@ -19,7 +23,7 @@ tx_params = {
     # "maxFeePerGas": "12321321",
 }
 qredo_extra_params = {
-    "chainID": 1,
+    "chainID": "3",
 }
 
 # Create the tx from details and send it to the custodian
