@@ -1,7 +1,16 @@
+import os
 from mmisdk import CustodianFactory
 
+# Instantiate the factory
 factory = CustodianFactory()
-custodian = factory.create_for("bitgo-test", "YOUR-TOKEN-BITGO-TEST")
+
+# Grab your token from an environment variable, or anywhere else
+token = os.environ["MMISDK_TOKEN_BITGO_TEST"]
+
+# Create the custodian, using the factory
+custodian = factory.create_for("bitgo-test", token)
+
+# Get the transaction
 transaction = custodian.get_transaction("0a4a244b-dbd4-4a4a-bc3d-0cf8f2f5f618")
 
 print(type(transaction))
