@@ -1,7 +1,17 @@
+import os
 from mmisdk import CustodianFactory
 
+# Instantiate the factory
 factory = CustodianFactory()
-custodian = factory.create_for("cactus-dev", "YOUR-REFRESH-TOKEN-CACTUS-DEV")
+
+# Grab your token from the environment, or anywhere else
+token = os.environ["MMISDK_TOKEN_CACTUS_DEV"]
+
+
+# Create the custodian, using the factory
+custodian = factory.create_for("cactus-dev", token)
+
+# Get the transaction
 transaction = custodian.get_transaction("5CM05NCLMRD888888000800", 5)
 
 print(type(transaction))
