@@ -1,7 +1,15 @@
-from mmisdk.custodian_factory import CustodianFactory
+import os
+from mmisdk.factory.custodian_factory import CustodianFactory
 
+# Instantiate the factory
 factory = CustodianFactory()
-custodian = factory.create_for("qredo-dev", "YOUR-REFRESH-TOKEN-QREDO-DEV")
+
+# Grab your token from the environment, or anywhere else
+token = os.environ["MMISDK_TOKEN_QREDO_DEV"]
+
+custodian = factory.create_for("qredo-dev", token)
+
+# Get the transaction
 transaction = custodian.get_transaction("2ELvFICFt3RnXWdyxjkMvFN80xr")
 
 print(type(transaction))
