@@ -53,7 +53,7 @@ class CactusAdapter(Custodian):
             data=tx_params_parsed.data,
             gasPrice=gasPrice,
             maxPriorityFeePerGas=maxPriorityFeePerGas,
-            maxFeePerGas=maxFeePerGas,
+            maxFeePerGas=maxFeePerGas
         )
         cactus_transaction_detail = self.client.create_transaction(extra_params_parsed.chainId, cactus_tx_params)
         return self.__map_cactus_transaction_to_transaction(cactus_transaction_detail)
@@ -69,7 +69,7 @@ class CactusAdapter(Custodian):
             gasPrice=cactus_transaction_detail.gasPrice,
             maxPriorityFeePerGas=cactus_transaction_detail.maxPriorityFeePerGas,
             maxFeePerGas=cactus_transaction_detail.maxFeePerGas,
-            nonce=cactus_transaction_detail.nonce,
+            nonce=cactus_transaction_detail.nonce if cactus_transaction_detail.nonce != "" else None,
             data=None,  # TODO Why no field "data" on the response from Cactus API?
             hash=cactus_transaction_detail.transactionHash,
             status=map_transaction_status(cactus_transaction_detail.transactionStatus, "Unknown"),
