@@ -1,9 +1,14 @@
 from enum import Enum
-from typing import Dict
+from typing import Dict, Union
 from typing import List
 from typing import Optional
+from pydantic import Field
 
-from pydantic import BaseModel
+from mmisdk.common.base_model import BaseModel
+from mmisdk.common.dec_string import DecString
+from mmisdk.common.empty_string import EmptyString
+from mmisdk.common.ethereum_address import EthereumAddress
+from mmisdk.common.hex_string import HexString
 
 
 class QredoTransactionEvent(BaseModel):
@@ -31,20 +36,20 @@ class QredoTransactionStatus(str, Enum):
 
 class QredoTransactionInfo(BaseModel):
     txID: str
-    txHash: str
+    txHash: Union[HexString, EmptyString]
     status: QredoTransactionStatus
     nonce: int
-    from_: str
-    to: str
-    value: str
-    gasPrice: Optional[str]
-    maxPriorityFeePerGas: Optional[str]
-    gasLimit: str
-    maxFeePerGas: Optional[str]
-    data: str
+    from_:  EthereumAddress = Field(None, alias="from")
+    to: EthereumAddress
+    value: DecString
+    gasLimit: DecString
+    maxPriorityFeePerGas: Optional[DecString]
+    maxFeePerGas: Optional[DecString]
+    gasPrice: Optional[DecString]
+    data: Union[HexString, EmptyString]
     rawTX: str
     createdBy: str
     network: str
-    chainID: str
+    chainID: DecString
     timestamps: Dict
     events: List[QredoTransactionEvent]
